# -*- coding: utf-8 -*-
#
# See LICENSE file for license and copyright information

# -- General configuration ------------------------------------------------

source_suffix  = '.rst'
master_doc     = 'zathura.1'
templates_path = ['_templates']

# -- Project configuration ------------------------------------------------

project   = 'zathura'
copyright = '2009-2015, pwmt.org'
version   = '0.2.7'
release   = '0.2.7'

# -- Options for manual page output ---------------------------------------

man_pages = [
    ('zathura.1', 'zathura', 'a document viewer', ['pwmt.org'], 1),
    ('zathurarc.5', 'zathurarc', 'zathura configuration file', ['pwmt.org'], 5)
]
